@@ -3,7 +3,7 @@ class Formatter:
     MAX_FIELD_LEN = 25
 
     def __init__(self):
-        self.fmt = "<green>{time}</green> |<blue>{name: <40}|{function: ^20}:{line: <3}</blue>|<level>{level:^6} | {message}</level>\n"
+        self.fmt = "<green>{time}</green> |<blue>{name: <40}</blue>|<level>{level:^6} | {message}</level>\n{exception}"
 
     def limit_len(self, record, field, length=MAX_FIELD_LEN):
         #Shorten field content
@@ -18,6 +18,5 @@ class Formatter:
 
     def format(self, record):
         self.limit_len(record,"name",40)
-        self.limit_len(record,"function",20)
         return self.fmt
 
